File 1339-Fix-typos-in-lib-mnesia.patch of Package erlang

From 9799620c069f043df34e423c71325183d5583e68 Mon Sep 17 00:00:00 2001
From: "Kian-Meng, Ang" <kianmeng@cpan.org>
Date: Tue, 21 Dec 2021 13:38:43 +0800
Subject: [PATCH] Fix typos in lib/mnesia

---
 lib/mnesia/doc/src/Mnesia_chap3.xmlsrc        |  2 +-
 lib/mnesia/doc/src/Mnesia_chap4.xmlsrc        |  4 ++--
 lib/mnesia/doc/src/Mnesia_chap7.xmlsrc        |  2 +-
 lib/mnesia/doc/src/mnesia.xml                 |  2 +-
 lib/mnesia/examples/bench/README              |  6 ++---
 lib/mnesia/examples/mnesia_tpcb.erl           |  2 +-
 lib/mnesia/src/mnesia.erl                     |  2 +-
 lib/mnesia/src/mnesia_backup.erl              |  2 +-
 lib/mnesia/src/mnesia_checkpoint.erl          |  4 ++--
 lib/mnesia/src/mnesia_controller.erl          | 10 ++++-----
 lib/mnesia/src/mnesia_dumper.erl              |  8 +++----
 lib/mnesia/src/mnesia_lib.erl                 |  8 +++----
 lib/mnesia/src/mnesia_loader.erl              |  6 ++---
 lib/mnesia/src/mnesia_locker.erl              | 16 +++++++-------
 lib/mnesia/src/mnesia_log.erl                 |  2 +-
 lib/mnesia/src/mnesia_recover.erl             |  8 +++----
 lib/mnesia/src/mnesia_schema.erl              | 20 ++++++++---------
 lib/mnesia/src/mnesia_snmp_hook.erl           |  4 ++--
 lib/mnesia/src/mnesia_subscr.erl              |  4 ++--
 lib/mnesia/src/mnesia_tm.erl                  | 16 +++++++-------
 lib/mnesia/test/mnesia_SUITE.erl              |  2 +-
 lib/mnesia/test/mnesia_atomicity_test.erl     | 22 +++++++++----------
 lib/mnesia/test/mnesia_config_backup.erl      |  2 +-
 lib/mnesia/test/mnesia_config_test.erl        |  2 +-
 lib/mnesia/test/mnesia_consistency_test.erl   |  2 +-
 lib/mnesia/test/mnesia_durability_test.erl    | 16 +++++++-------
 lib/mnesia/test/mnesia_evil_coverage_test.erl |  6 ++---
 lib/mnesia/test/mnesia_isolation_test.erl     | 16 +++++++-------
 lib/mnesia/test/mnesia_recovery_test.erl      |  4 ++--
 lib/mnesia/test/mnesia_test_lib.erl           |  4 ++--
 lib/mnesia/test/mnesia_tpcb.erl               |  2 +-
 lib/mnesia/test/mnesia_trans_access_test.erl  |  4 ++--
 32 files changed, 105 insertions(+), 105 deletions(-)

diff --git a/lib/mnesia/doc/src/Mnesia_chap3.xmlsrc b/lib/mnesia/doc/src/Mnesia_chap3.xmlsrc
index 41c85d97f1..eb25f57787 100644
--- a/lib/mnesia/doc/src/Mnesia_chap3.xmlsrc
+++ b/lib/mnesia/doc/src/Mnesia_chap3.xmlsrc
@@ -177,7 +177,7 @@ Transformer =
       which identifies the particular record in that table. The
       combination of the table name and a key is an arity two tuple
       <c>{Tab, Key}</c> called the OID. For more information about
-      the relationship beween the record name and the table name, see
+      the relationship between the record name and the table name, see
       <seealso marker="Mnesia_chap4#recordnames_tablenames">Record Names versus Table Names</seealso>.
     </p>
     <p>What makes the <c>Mnesia</c> data model an extended relational model
diff --git a/lib/mnesia/doc/src/Mnesia_chap4.xmlsrc b/lib/mnesia/doc/src/Mnesia_chap4.xmlsrc
index fd9bea8323..937caf10f0 100644
--- a/lib/mnesia/doc/src/Mnesia_chap4.xmlsrc
+++ b/lib/mnesia/doc/src/Mnesia_chap4.xmlsrc
@@ -520,10 +520,10 @@
         <list type="ordered">
           <item>It is much more efficient.
           </item>
-          <item>The funcion
+          <item>The function
            <seealso marker="mnesia#dirty_update_counter/2">dirty_update_counter/2</seealso>
            is performed as an atomic operation although it is not protected
-           by a transaction. Therfore no table update is lost if two
+           by a transaction. Therefore no table update is lost if two
            processes simultaneously execute the function
           <c>dirty_update_counter/2</c>.
           </item>
diff --git a/lib/mnesia/doc/src/Mnesia_chap7.xmlsrc b/lib/mnesia/doc/src/Mnesia_chap7.xmlsrc
index ef5e136446..ae3db94750 100644
--- a/lib/mnesia/doc/src/Mnesia_chap7.xmlsrc
+++ b/lib/mnesia/doc/src/Mnesia_chap7.xmlsrc
@@ -720,7 +720,7 @@ dets:close(N).</pre>
         </item>
         <item><c>Source</c> and <c>Target</c> are opaque data used
          exclusively by the modules <c>SourceMod</c> and
-         <c>TargetMod</c> for initializing the backup medias.
+         <c>TargetMod</c> for initializing the backup media.
         </item>
         <item><c>Acc</c> is an initial accumulator value.
         </item>
diff --git a/lib/mnesia/doc/src/mnesia.xml b/lib/mnesia/doc/src/mnesia.xml
index 9791a57610..b79398f302 100644
--- a/lib/mnesia/doc/src/mnesia.xml
+++ b/lib/mnesia/doc/src/mnesia.xml
@@ -1153,7 +1153,7 @@ mnesia:create_table(person,
           or negative number. However, counters can never become less
           than zero. There are two significant differences between
           this function and the action of first reading the record,
-          performing the arithmetics, and then writing the record:</p>
+          performing the arithmetic, and then writing the record:</p>
         <list type="bulleted">
           <item>It is much more efficient.
           </item>
diff --git a/lib/mnesia/examples/bench/README b/lib/mnesia/examples/bench/README
index b8209b19b8..52225c5f7d 100644
--- a/lib/mnesia/examples/bench/README
+++ b/lib/mnesia/examples/bench/README
@@ -45,7 +45,7 @@ In order to be able to automatically start remote Erlang nodes,
 you need to:
 
  - put the $ERL_TOP/bin directory in your path on all nodes
- - bind IP adresses to hostnames (e.g via DNS or /etc/hosts)
+ - bind IP addresses to hostnames (e.g via DNS or /etc/hosts)
  - enable usage of ssh so it does not prompt for password
 
 If you cannot achieve this, it is possible to run the benchmark
@@ -79,11 +79,11 @@ Given some arguments such as
 
    Args = ['YourConfigFile', {statistics_detail, debug}].
 
-the invokation of
+the invocation of
 
    bench:run(Args).
 
-is equivivalent with:
+is equivalent with:
 
    SlaveNodes = bench:start_all(Args).
    bench:populate(Args).
diff --git a/lib/mnesia/examples/mnesia_tpcb.erl b/lib/mnesia/examples/mnesia_tpcb.erl
index fb39ee321d..2f2f3a3eb9 100644
--- a/lib/mnesia/examples/mnesia_tpcb.erl
+++ b/lib/mnesia/examples/mnesia_tpcb.erl
@@ -35,7 +35,7 @@
 %%   a database system.
 %%
 %%   The definition of the TPC-B states lots of detailed rules and
-%%   conditions that must be fullfilled, e.g. how the ACID (atomicity,
+%%   conditions that must be fulfilled, e.g. how the ACID (atomicity,
 %%   consistency, isolation and durability) properties are verified,
 %%   how the random numbers must be distributed, minimum sizes of
 %%   the different types of records, minimum duration of the benchmark,
diff --git a/lib/mnesia/src/mnesia.erl b/lib/mnesia/src/mnesia.erl
index 35e2d8dd10..bb5858b3f8 100644
--- a/lib/mnesia/src/mnesia.erl
+++ b/lib/mnesia/src/mnesia.erl
@@ -513,7 +513,7 @@ wrap_trans(State, Fun, Args, Retries, Mod, Kind) ->
 %% read lock is only set on the first node
 %% Nodes may either be a list of nodes or one node as an atom
 %% Mnesia on all Nodes must be connected to each other, but
-%% it is not neccessary that they are up and running.
+%% it is not necessary that they are up and running.
 -spec lock(LockItem, LockKind) -> list() | tuple() | no_return() when
       LockItem :: {'record', table(), Key::term()} |
                   {'table',  table()} |
diff --git a/lib/mnesia/src/mnesia_backup.erl b/lib/mnesia/src/mnesia_backup.erl
index 719e010c17..3bda0ab5f6 100644
--- a/lib/mnesia/src/mnesia_backup.erl
+++ b/lib/mnesia/src/mnesia_backup.erl
@@ -30,7 +30,7 @@
 %% write an own module the same interface as mnesia_backup and
 %% configure Mnesia so the alternate module performs the actual
 %% accesses to the backup media. This means that the user may put
-%% the backup on medias that Mnesia does not know about, possibly
+%% the backup on media that Mnesia does not know about, possibly
 %% on hosts where Erlang is not running.
 %%
 %% The OpaqueData argument is never interpreted by other parts of
diff --git a/lib/mnesia/src/mnesia_checkpoint.erl b/lib/mnesia/src/mnesia_checkpoint.erl
index c67c740036..fce588444b 100644
--- a/lib/mnesia/src/mnesia_checkpoint.erl
+++ b/lib/mnesia/src/mnesia_checkpoint.erl
@@ -306,7 +306,7 @@ really_retain(Name, Tab) ->
 %%
 %% {min, MinTabs}
 %%   Minimize redundancy and only keep checkpoint info together with
-%%   one replica, preferrably at the local node. If any node involved
+%%   one replica, preferably at the local node. If any node involved
 %%   the checkpoint goes down, the checkpoint is deactivated.
 %%
 %% {max, MaxTabs}
@@ -319,7 +319,7 @@ really_retain(Name, Tab) ->
 %% {ram_overrides_dump, Tabs}
 %%   Only applicable for ram_copies. Bool controls which versions of
 %%   the records that should be included in the checkpoint state.
-%%   true means that the latest comitted records in ram (i.e. the
+%%   true means that the latest committed records in ram (i.e. the
 %%   records that the application accesses) should be included
 %%   in the checkpoint. false means that the records dumped to
 %%   dat-files (the records that will be loaded at startup) should
diff --git a/lib/mnesia/src/mnesia_controller.erl b/lib/mnesia/src/mnesia_controller.erl
index f6ef0bd1ae..e5acb66919 100644
--- a/lib/mnesia/src/mnesia_controller.erl
+++ b/lib/mnesia/src/mnesia_controller.erl
@@ -341,7 +341,7 @@ get_network_copy(Tid, Tab, Cs) ->
         ok ->
             Reason = {dumper,{add_table_copy, Tid}},
             Work = #net_load{table = Tab,reason = Reason,cstruct = Cs},
-            %% I'll need this cause it's linked trough the subscriber
+            %% I'll need this cause it's linked through the subscriber
             %% might be solved by using monitor in subscr instead.
             process_flag(trap_exit, true),
             Load = load_table_fun(Work),
@@ -374,7 +374,7 @@ get_network_copy(Tid, Tab, Cs) ->
 %%   no need for sync, since mnesia_controller not started yet
 %% schema_trans ->
 %%   already synced with mnesia_controller since the dumper
-%%   is syncronously started from mnesia_controller
+%%   is synchronously started from mnesia_controller
 
 create_table(Tab) ->
     {loaded, ok} = mnesia_loader:disc_load_table(Tab, {dumper,create_table}).
@@ -1016,7 +1016,7 @@ handle_cast(Msg, State) when State#state.schema_is_merged /= true ->
 
 %% This must be done after schema_is_merged otherwise adopt_orphan
 %% might trigger a table load from wrong nodes as a result of that we don't
-%% know which tables we can load safly first.
+%% know which tables we can load safely first.
 handle_cast({im_running, Node, NewFriends}, State) ->
     LocalTabs = mnesia_lib:local_active_tables() -- [schema],
     RemoveLocalOnly = fun(Tab) -> not val({Tab, local_content}) end,
@@ -1436,7 +1436,7 @@ orphan_tables([Tab | Tabs], Node, Ns, Local, Remote) ->
     case lists:member(Node, DiscCopyHolders) of
 	_ when BeingCreated == true ->
 	    orphan_tables(Tabs, Node, Ns, Local, Remote);
-	_ when Read == node() -> %% Allready loaded
+	_ when Read == node() -> %% Already loaded
 	    orphan_tables(Tabs, Node, Ns, Local, Remote);
 	true when Active == [] ->
 	    case DiscCopyHolders -- Ns of
@@ -2146,7 +2146,7 @@ load_and_reply(ReplyTo, Worker) ->
     spawn_link(SendAndReply).
 
 %% Now it is time to load the table
-%% but first we must check if it still is neccessary
+%% but first we must check if it still is necessary
 load_table_fun(#net_load{cstruct=Cs, table=Tab, reason=Reason, opt_reply_to=ReplyTo}) ->
     LocalC = val({Tab, local_content}),
     AccessMode = val({Tab, access_mode}),
diff --git a/lib/mnesia/src/mnesia_dumper.erl b/lib/mnesia/src/mnesia_dumper.erl
index 82e37ca4d8..d5e45863f4 100644
--- a/lib/mnesia/src/mnesia_dumper.erl
+++ b/lib/mnesia/src/mnesia_dumper.erl
@@ -526,8 +526,8 @@ disc_delete_table(Tab, Storage) ->
 disc_delete_indecies(Tab, Cs, Storage) ->
     case storage_semantics(Storage) of
 	disc_only_copies ->
-	    Indecies = Cs#cstruct.index,
-	    mnesia_index:del_transient(Tab, Indecies, Storage);
+	    Indices = Cs#cstruct.index,
+	    mnesia_index:del_transient(Tab, Indices, Storage);
 	_ ->
 	    ok
     end.
@@ -815,7 +815,7 @@ insert_op(Tid, _, {op, create_table, TabDef}, InPlace, InitBy) ->
 			ram_copies ->
 			    ignore;
 			_ ->
-			    %% Indecies are still created by loader
+			    %% Indices are still created by loader
 			    disc_delete_indecies(Tab, Cs, Storage)
 			    %% disc_delete_table(Tab, Storage)
 		    end,
@@ -1433,7 +1433,7 @@ chunk_from_log(eof, _, _, _) ->
 %%
 %% This is a poor mans substitute for a fair scheduler algorithm
 %% in the Erlang emulator. The mnesia_dumper process performs many
-%% costly BIF invokations and must pay for this. But since the
+%% costly BIF invocations and must pay for this. But since the
 %% Emulator does not handle this properly we must compensate for
 %% this with some form of load regulation of ourselves in order to
 %% not steal all computation power in the Erlang Emulator and make
diff --git a/lib/mnesia/src/mnesia_lib.erl b/lib/mnesia/src/mnesia_lib.erl
index 4dce5cefc0..37380fba87 100644
--- a/lib/mnesia/src/mnesia_lib.erl
+++ b/lib/mnesia/src/mnesia_lib.erl
@@ -568,10 +568,10 @@ set_remote_where_to_read(Tab, Ignore) ->
 	end,    
     Available = mnesia_lib:intersect(val({current, db_nodes}), Valid -- Ignore),    
     DiscOnlyC = val({Tab, disc_only_copies}),
-    Prefered  = Available -- DiscOnlyC,
+    Preferred  = Available -- DiscOnlyC,
     if
-	Prefered /= [] ->
-	    set({Tab, where_to_read}, hd(Prefered));
+	Preferred /= [] ->
+	    set({Tab, where_to_read}, hd(Preferred));
 	Available /= [] ->
 	    set({Tab, where_to_read}, hd(Available));
 	true ->
@@ -936,7 +936,7 @@ error_desc(mnesia_down) -> "A transaction involving objects at some remote "
                            "node which died while transaction was executing"
                            "*and* object(s) are no longer available elsewhere"
                            "in the network";
-error_desc(not_a_db_node) -> "A node which is non existant in "
+error_desc(not_a_db_node) -> "A node which is non existent in "
                               "the schema was mentioned";
 error_desc(bad_type)            -> "Bad type on some provided arguments";
 error_desc(node_not_running)    -> "Node not running";
diff --git a/lib/mnesia/src/mnesia_loader.erl b/lib/mnesia/src/mnesia_loader.erl
index b9285b3d71..b950b67be0 100644
--- a/lib/mnesia/src/mnesia_loader.erl
+++ b/lib/mnesia/src/mnesia_loader.erl
@@ -260,12 +260,12 @@ init_receiver(Node, Tab,Storage,Cs,Reason) ->
 		mnesia_locker:rlock(Tid, Ts#tidstore.store, {schema, Tab}),
 		%% Check that table still exists
 		Active = val({Tab, active_replicas}),
-		%% Check that we havn't loaded it already
+		%% Check that we haven't loaded it already
 		case val({Tab,where_to_read}) == node() of
 		    true -> ok;
 		    _ ->
 			%% And that sender still got a copy
-			%% (something might have happend while
+			%% (something might have happened while
 			%% we where waiting for the lock)
 			true = lists:member(Node, Active),
 			{SenderPid, TabSize, DetsData} =
@@ -329,7 +329,7 @@ table_init_fun(SenderPid, Storage) ->
 	    ok
     end.
 
-%% Add_table_copy get's it's own locks.
+%% Add_table_copy gets it's own locks.
 start_receiver(Tab,Storage,Cs,SenderPid,TabSize,DetsData,{dumper,{add_table_copy,_}}) ->
     Init = table_init_fun(SenderPid, Storage),
     case do_init_table(Tab,Storage,Cs,SenderPid,TabSize,DetsData,self(), Init) of
diff --git a/lib/mnesia/src/mnesia_locker.erl b/lib/mnesia/src/mnesia_locker.erl
index d6eafd75b3..1dc780e885 100644
--- a/lib/mnesia/src/mnesia_locker.erl
+++ b/lib/mnesia/src/mnesia_locker.erl
@@ -201,14 +201,14 @@ loop(State) ->
 	    end;
 
 	%% If test_set_sticky fails, we send this to all nodes
-	%% after aquiring a real write lock on Oid
+	%% after acquiring a real write lock on Oid
 
 	{stick, {Tab, _}, N} ->
 	    ?ets_insert(mnesia_sticky_locks, {Tab, N}),
 	    loop(State);
 
 	%% The caller which sends this message, must have first
-	%% aquired a write lock on the entire table
+	%% acquired a write lock on the entire table
 	{unstick, Tab} ->
 	    ?ets_delete(mnesia_sticky_locks, Tab),
 	    loop(State);
@@ -680,7 +680,7 @@ ix_read_res(Tab,IxKey,Pos) ->
 %% ********************* end server code ********************
 %% The following code executes at the client side of a transactions
 
-%% Aquire a write lock, but do a read, used by
+%% Acquire a write lock, but do a read, used by
 %% mnesia:wread/1
 
 rwlock(Tid, Store, Oid) ->
@@ -743,7 +743,7 @@ check_majority(Tab, HaveNs) ->
 	    ok
     end.
 
-%% aquire a sticky wlock, a sticky lock is a lock
+%% acquire a sticky wlock, a sticky lock is a lock
 %% which remains at this node after the termination of the
 %% transaction.
 
@@ -840,11 +840,11 @@ dirty_sticky_lock(Tab, Key, Nodes, Lock) ->
 sticky_wlock_table(Tid, Store, Tab) ->
     sticky_lock(Tid, Store, {Tab, ?ALL}, write).
 
-%% aquire a wlock on Oid
+%% acquire a wlock on Oid
 %% We store a {Tabname, write, Tid} in all locktables
 %% on all nodes containing a copy of Tabname
 %% We also store an item {{locks, Tab, Key}, write} in the
-%% local store when we have aquired the lock.
+%% local store when we have acquired the lock.
 %%
 wlock(Tid, Store, Oid) ->
     wlock(Tid, Store, Oid, _CheckMajority = true).
@@ -913,7 +913,7 @@ get_wlocks_on_nodes([Node | Tail], Orig, Store, Request, Oid) ->
     case node() of
 	Node -> %% Local done try one more
 	    get_wlocks_on_nodes(Tail, Orig, Store, Request, Oid);
-	_ ->    %% The first succeded cont with the rest
+	_ ->    %% The first succeeded cont with the rest
 	    get_wlocks_on_nodes(Tail, Store, Request),
 	    receive_wlocks(Tail, Orig, Store, Oid)
     end;
@@ -1027,7 +1027,7 @@ return_granted_or_nodes(_           , _Nodes) -> granted.
 %% locks table on the node where we actually do pick up the object
 %% and we also store an item {lock, Oid, read} in our local store
 %% so that we can release any locks we hold when we commit.
-%% This function not only aquires a read lock, but also reads the object
+%% This function not only acquires a read lock, but also reads the object
 
 %% Oid's are always {Tab, Key} tuples
 rlock(Tid, Store, Oid) ->
diff --git a/lib/mnesia/src/mnesia_log.erl b/lib/mnesia/src/mnesia_log.erl
index e22affb400..b1514bfbe6 100644
--- a/lib/mnesia/src/mnesia_log.erl
+++ b/lib/mnesia/src/mnesia_log.erl
@@ -48,7 +48,7 @@
 %%   with the same interface as mnesia_backup and configure
 %%   Mnesia so the alternate module performs the actual accesses
 %%   to the backup media. This means that the user may put the
-%%   backup on medias that Mnesia does not know about possibly on
+%%   backup on media that Mnesia does not know about possibly on
 %%   hosts where Erlang is not running.
 %%
 %% All these logs have to some extent a common structure.
diff --git a/lib/mnesia/src/mnesia_recover.erl b/lib/mnesia/src/mnesia_recover.erl
index 15c5ccdb84..820e142994 100644
--- a/lib/mnesia/src/mnesia_recover.erl
+++ b/lib/mnesia/src/mnesia_recover.erl
@@ -1083,7 +1083,7 @@ merge_decisions(Node, D, NewD0) ->
 		NewD#decision.outcome == aborted ->
 		    %% Interesting! We have already committed,
 		    %% but someone else has aborted. Now we
-		    %% have a nice little inconcistency. The
+		    %% have a nice little inconsistency. The
 		    %% other guy (or some one else) has 
 		    %% enforced a recovery decision when
 		    %% max_wait_for_decision was exceeded.
@@ -1096,11 +1096,11 @@ merge_decisions(Node, D, NewD0) ->
 		    OldD#decision{outcome = aborted};
 
 		OldD#decision.outcome == aborted ->
-		    %% aborted overrrides anything
+		    %% aborted overrides anything
 		    OldD#decision{outcome = aborted};
 
 		NewD#decision.outcome == aborted ->
-		    %% aborted overrrides anything
+		    %% aborted overrides anything
 		    OldD#decision{outcome = aborted};
 
 		OldD#decision.outcome == committed,
@@ -1236,7 +1236,7 @@ arrange([To | ToNodes], D, Acc, ForceSend) when is_record(D, decision) ->
 
 arrange([To | ToNodes], {trans_tid, serial, Serial}, Acc, ForceSend) ->
     %% Do the lamport thing plus release the others
-    %% from uncertainity.
+    %% from uncertainty.
     Acc2 = add_decision(To, {trans_tid, serial, Serial}, Acc),
     arrange(ToNodes, {trans_tid, serial, Serial}, Acc2, ForceSend);
 
diff --git a/lib/mnesia/src/mnesia_schema.erl b/lib/mnesia/src/mnesia_schema.erl
index ed7f362cf6..994c1b070e 100644
--- a/lib/mnesia/src/mnesia_schema.erl
+++ b/lib/mnesia/src/mnesia_schema.erl
@@ -957,13 +957,13 @@ get_ext_types_disc_() ->
             []
     end.
 
-%% Convert attribute name to integer if neccessary
+%% Convert attribute name to integer if necessary
 attr_tab_to_pos(_Tab, Pos) when is_integer(Pos) ->
     Pos;
 attr_tab_to_pos(Tab, Attr) ->
     attr_to_pos(Attr, val({Tab, attributes})).
 
-%% Convert attribute name to integer if neccessary
+%% Convert attribute name to integer if necessary
 attr_to_pos({_} = P, _) -> P;
 attr_to_pos(Pos, _Attrs) when is_integer(Pos) ->
     Pos;
@@ -1024,14 +1024,14 @@ verify_cstruct(#cstruct{} = Cs) ->
 
 expand_index_attrs(#cstruct{index = Ix, attributes = Attrs,
 			    name = Tab} = Cs) ->
-    Prefered = prefered_index_types(Cs),
-    expand_index_attrs(Ix, Tab, Attrs, Prefered).
+    Preferred = prefered_index_types(Cs),
+    expand_index_attrs(Ix, Tab, Attrs, Preferred).
 
-expand_index_attrs(Ix, Tab, Attrs, Prefered) ->
+expand_index_attrs(Ix, Tab, Attrs, Preferred) ->
     lists:map(fun(P) when is_integer(P); is_atom(P) ->
-		      {attr_to_pos(P, Attrs), Prefered};
+		      {attr_to_pos(P, Attrs), Preferred};
 		 ({A} = P) when is_atom(A) ->
-		      {P, Prefered};
+		      {P, Preferred};
 		 ({P, Type}) ->
 		      {attr_to_pos(P, Attrs), Type};
 		 (_Other) ->
@@ -1352,7 +1352,7 @@ check_active([], _Expl, _Tab) ->
 
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%% Function for definining an external backend type
+%% Function for defining an external backend type
 
 add_backend_type(Name, Module) ->
     case schema_transaction(fun() -> do_add_backend_type(Name, Module) end) of
@@ -3093,7 +3093,7 @@ ext_real_suffixes(Ext) ->
 		    [M || {_,M} <- Ext])
     catch
         error:E ->
-            verbose("Cant find real ext suffixes (~p)~n", [E]),
+            verbose("Can't find real ext suffixes (~p)~n", [E]),
             []
     end.
 
@@ -3102,7 +3102,7 @@ ext_tmp_suffixes(Ext) ->
 		    [M || {_,M} <- Ext])
     catch
         error:E ->
-            verbose("Cant find tmp ext suffixes (~p)~n", [E]),
+            verbose("Can't find tmp ext suffixes (~p)~n", [E]),
             []
     end.
 
diff --git a/lib/mnesia/src/mnesia_snmp_hook.erl b/lib/mnesia/src/mnesia_snmp_hook.erl
index 58a20c6051..cedd9b6117 100644
--- a/lib/mnesia/src/mnesia_snmp_hook.erl
+++ b/lib/mnesia/src/mnesia_snmp_hook.erl
@@ -134,7 +134,7 @@ keys_to_oid(N, Key, Oid, Types) ->
 %%--------------------------------------------------
 %% The reverse of the above, i.e. snmp oid to mnesia key.
 %% This can be lookup up in tree but that might be on a remote node.
-%% It's probably faster to look it up, but use when it migth be remote 
+%% It's probably faster to look it up, but use when it might be remote 
 oid_to_key(Oid, Tab) ->
     [{key, Types}] = mnesia_lib:val({Tab,snmp}),
     oid_to_key_1(Types, Oid). 
@@ -208,7 +208,7 @@ get_next_index(Name, RowIndex) ->
 %% Purpose: Get the mnesia key corresponding to the RowIndex.
 %% Args: Name is the name of the table (atom)
 %%       RowIndex is an Oid
-%% Returns: {ok, Key} | undefiend
+%% Returns: {ok, Key} | undefined
 %%-----------------------------------------------------------------
 get_mnesia_key(Name, RowIndex) ->
     Tree = mnesia_lib:val({Name, {index, snmp}}),
diff --git a/lib/mnesia/src/mnesia_subscr.erl b/lib/mnesia/src/mnesia_subscr.erl
index 21a308cfb6..cba0ca9dd5 100644
--- a/lib/mnesia/src/mnesia_subscr.erl
+++ b/lib/mnesia/src/mnesia_subscr.erl
@@ -148,7 +148,7 @@ report_table_event(Tab, Tid, Obj, Op) ->
 	    end
     end.
 
-%% Backwards compatible for the moment when mnesia_tm get's updated!
+%% Backwards compatible for the moment when mnesia_tm gets updated!
 report_table_event(Subscr, Tab, Tid, Obj, Op) ->
     report_table_event(Subscr, Tab, Tid, Obj, Op, undefined).
 
@@ -173,7 +173,7 @@ report_table_event({subscribers, S1, S2}, Tab, Tid, Obj, Op, Old) ->
     Extended = what(Tab, Tid, Obj, Op, Old), 
     deliver(S2, Extended);
 
-%% Backwards compatible for the moment when mnesia_tm get's updated!
+%% Backwards compatible for the moment when mnesia_tm gets updated!
 report_table_event({subscribers, Subscr}, Tab, Tid, Obj, Op, Old) ->    
     report_table_event({subscribers, Subscr, []}, Tab, Tid, Obj, Op, Old).
 
diff --git a/lib/mnesia/src/mnesia_tm.erl b/lib/mnesia/src/mnesia_tm.erl
index 9e9661ff60..0c66853a4b 100644
--- a/lib/mnesia/src/mnesia_tm.erl
+++ b/lib/mnesia/src/mnesia_tm.erl
@@ -181,7 +181,7 @@ tmpid(Pid) ->
 
 %% Returns a list of participant transaction Tid's
 mnesia_down(Node) ->
-    %% Syncronously call needed in order to avoid
+    %% Synchronously call needed in order to avoid
     %% race with mnesia_tm's coordinator processes
     %% that may restart and acquire new locks.
     %% mnesia_monitor takes care of the sync
@@ -598,7 +598,7 @@ recover_coordinator(Tid, Etabs) ->
 		    recover_coordinator(Tid, Protocol, Outcome, Local, DiscNs, RamNs),
 		    ?eval_debug_fun({?MODULE, recover_coordinator, post},
 				    [{tid, Tid}, {outcome, Outcome}, {prot, Protocol}]);
-		false ->  %% When killed before store havn't been copied to
+		false ->  %% When killed before store haven't been copied to
 		    ok    %% to the new nested trans store.
 	    end
     catch _:Reason ->
@@ -881,7 +881,7 @@ try_again(_) -> no.
 %% We can only restart toplevel transactions.
 %% If a deadlock situation occurs in a nested transaction
 %% The whole thing including all nested transactions need to be
-%% restarted. The stack is thus popped by a consequtive series of
+%% restarted. The stack is thus popped by a consecutive series of
 %% exit({aborted, #cyclic{}}) calls
 
 restart(Mod, Tid, Ts, Fun, Args, Factor0, Retries0, Type, Why) ->
@@ -1070,7 +1070,7 @@ dirty(Protocol, Item) ->
 	async_dirty ->
 	    %% Send commit records to the other involved nodes,
 	    %% but do only wait for one node to complete.
-	    %% Preferrably, the local node if possible.
+	    %% Preferably, the local node if possible.
 
 	    ReadNode = val({Tab, where_to_read}),
 	    {WaitFor, FirstRes} = async_send_dirty(Tid, CR, Tab, ReadNode),
@@ -1088,7 +1088,7 @@ dirty(Protocol, Item) ->
 %% This is the commit function, The first thing it does,
 %% is to find out which nodes that have been participating
 %% in this particular transaction, all of the mnesia_locker:lock*
-%% functions insert the names of the nodes where it aquires locks
+%% functions insert the names of the nodes where it acquires locks
 %% into the local shadow Store
 %% This function exacutes in the context of the user process
 t_commit(Type) ->
@@ -1379,7 +1379,7 @@ multi_commit(read_only, _Maj = [], Tid, CR, _Store) ->
 
 multi_commit(sym_trans, _Maj = [], Tid, CR, Store) ->
     %% This lightweight commit protocol is used when all
-    %% the involved tables are replicated symetrically.
+    %% the involved tables are replicated symmetrically.
     %% Their storage types must match on each node.
     %%
     %% 1  Ask the other involved nodes if they want to commit
@@ -1431,7 +1431,7 @@ multi_commit(sym_trans, _Maj = [], Tid, CR, Store) ->
 
 multi_commit(sync_sym_trans, _Maj = [], Tid, CR, Store) ->
     %%   This protocol is the same as sym_trans except that it
-    %%   uses syncronized calls to disk_log and syncronized commits
+    %%   uses synchronized calls to disk_log and synchronized commits
     %%   when several nodes are involved.
 
     {DiscNs, RamNs} = commit_nodes(CR, [], []),
@@ -1763,7 +1763,7 @@ commit_participant(Protocol, Coord, Tid, Bin, C0, DiscNs, _RamNs) ->
 
 do_abort(Tid, Bin) when is_binary(Bin) ->
     %% Possible optimization:
-    %% If we want we could pass arround a flag
+    %% If we want we could pass around a flag
     %% that tells us whether the binary contains
     %% schema ops or not. Only if the binary
     %% contains schema ops there are meningful
diff --git a/lib/mnesia/test/mnesia_SUITE.erl b/lib/mnesia/test/mnesia_SUITE.erl
index 5e95e1dce7..711d4b86d3 100644
--- a/lib/mnesia/test/mnesia_SUITE.erl
+++ b/lib/mnesia/test/mnesia_SUITE.erl
@@ -42,7 +42,7 @@ suite() -> [{ct_hooks,[{ts_install_cth,[{nodenames,2}]}]}].
 
 %% Verify that Mnesia really is a distributed real-time DBMS.
 %% This is the test suite of the Mnesia DBMS. The test suite
-%% covers many aspects of usage and is indended to be developed
+%% covers many aspects of usage and is intended to be developed
 %% incrementally. The test suite is divided into a hierarchy of test
 %% suites where the leafs actually implements the test cases.
 %% The intention of each test case and sub test suite can be
diff --git a/lib/mnesia/test/mnesia_atomicity_test.erl b/lib/mnesia/test/mnesia_atomicity_test.erl
index 4764f9e7c0..c944fb4cdb 100644
--- a/lib/mnesia/test/mnesia_atomicity_test.erl
+++ b/lib/mnesia/test/mnesia_atomicity_test.erl
@@ -83,7 +83,7 @@ explicit_abort_in_middle_of_trans(Config
     %% Start a transaction on one node
     {success, [A]} = ?start_activities([Node1]),
 
-    %% store an object in the Tab - first tranaction
+    %% store an object in the Tab - first transaction
     ?start_transactions([A]),
     A ! fun() ->
 		mnesia:write(Rec1A)	% returns ok when successful
@@ -108,7 +108,7 @@ explicit_abort_in_middle_of_trans(Config
     %% Start a second  transactionprocess, after the first failed
     {success, [B]} = ?start_activities([Node1]),
 
-    %% check, whether the interupted transaction had no influence on the db
+    %% check, whether the interrupted transaction had no influence on the db
     ?start_transactions([B]),
     B ! fun() ->
 		?match([Rec1A], mnesia:read({Tab, 1})),
@@ -135,7 +135,7 @@ runtime_error_in_middle_of_trans(Config)
     %% Start a transaction on one node
     {success, [A]} = ?start_activities([Node1]),
 
-    %% store an object in the Tab - first tranaction
+    %% store an object in the Tab - first transaction
     ?start_transactions([A]),
     A ! fun() ->
 		mnesia:write(Rec1A)	% returns ok when successful
@@ -160,7 +160,7 @@ runtime_error_in_middle_of_trans(Config)
     %% Start a second  transactionprocess, after the first failed
     {success, [B]} = ?start_activities([Node1]),
 
-    %% check, whether the interupted transaction had no influence on the db
+    %% check, whether the interrupted transaction had no influence on the db
     ?start_transactions([B]),
     B ! fun() ->
 		?match([Rec1A], mnesia:read({Tab, 1})),
@@ -187,7 +187,7 @@ kill_self_in_middle_of_trans(Config) whe
     %% Start a transaction on one node
     {success, [A]} = ?start_activities([Node1]),
 
-    %% store an object in the Tab - first tranaction
+    %% store an object in the Tab - first transaction
     ?start_transactions([A]),
     A ! fun() ->
 		mnesia:write(Rec1A)	% returns ok when successful
@@ -216,7 +216,7 @@ kill_self_in_middle_of_trans(Config) whe
     %% Start a second  transactionprocess, after the first failed
     {success, [B]} = ?start_activities([Node1]),
 
-    %% check, whether the interupted transaction had no influence on the db
+    %% check, whether the interrupted transaction had no influence on the db
     ?start_transactions([B]),
     B ! fun() ->
 		?match([Rec1A], mnesia:read({Tab, 1})),
@@ -243,7 +243,7 @@ throw_in_middle_of_trans(Config) when is
     %% Start a transaction on one node
     {success, [A]} = ?start_activities([Node1]),
 
-    %% store an object in the Tab - first tranaction
+    %% store an object in the Tab - first transaction
     ?start_transactions([A]),
     A ! fun() ->
 		mnesia:write(Rec1A)	% returns ok when successful
@@ -269,7 +269,7 @@ throw_in_middle_of_trans(Config) when is
     %% Start a second  transactionprocess, after the first failed
     {success, [B]} = ?start_activities([Node1]),
 
-    %% check, whether the interupted transaction had no influence on the db
+    %% check, whether the interrupted transaction had no influence on the db
     ?start_transactions([B]),
     B ! fun() ->
 		?match([Rec1A], mnesia:read({Tab, 1})),
@@ -542,7 +542,7 @@ start_lock_waiter(BlockOpA, BlockOpB, Config) ->
     io:format("waiting for A (~p on ~p) to be in the queue ~n", [A, [N1, N2]]),
     wait_for_a(A, [N1, N2]),
 
-    io:format("Queus ~p~n",
+    io:format("Queues ~p~n",
 	      [[{N,rpc:call(N, mnesia, system_info, [lock_queue])} || N <- Nodes]]),
 
     KillNode = node(B),
@@ -743,7 +743,7 @@ start_restart_check(RestartOp, ReplicaNeed, Config) ->
     Wait(Wait),
     A ! go_ahead,
 
-    %% the sticky write doesnt work on remote nodes !!!
+    %% the sticky write doesn't work on remote nodes !!!
     ExpectedMsg =
 	case RestartOp of
 	    sw when ReplicaNeed == two ->
@@ -765,7 +765,7 @@ start_restart_check(RestartOp, ReplicaNeed, Config) ->
 
 
     %%  the expected result depends on the transaction of
-    %%  fun A - when that doesnt change the object in the
+    %%  fun A - when that doesn't change the object in the
     %%  table (e.g. it is a read) then the predefined
     %%  value {Tabname, 1, c} is expected to be the result here
 
diff --git a/lib/mnesia/test/mnesia_config_backup.erl b/lib/mnesia/test/mnesia_config_backup.erl
index 239101ca92..f6dddb4672 100644
--- a/lib/mnesia/test/mnesia_config_backup.erl
+++ b/lib/mnesia/test/mnesia_config_backup.erl
@@ -36,7 +36,7 @@
 %% write an own module the same interface as mnesia_backup and
 %% configure Mnesia so the alternate module performs the actual
 %% accesses to the backup media. This means that the user may put
-%% the backup on medias that Mnesia does not know about, possibly
+%% the backup on media that Mnesia does not know about, possibly
 %% on hosts where Erlang is not running.
 %%
 %% The OpaqueData argument is never interpreted by other parts of
diff --git a/lib/mnesia/test/mnesia_config_test.erl b/lib/mnesia/test/mnesia_config_test.erl
index 7f584e35f9..79872ab33a 100644
--- a/lib/mnesia/test/mnesia_config_test.erl
+++ b/lib/mnesia/test/mnesia_config_test.erl
@@ -937,7 +937,7 @@ start_first_one_disc_less_then_two_more_disc_less(Config) when is_list(Config) -
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 schema_location_and_extra_db_nodes_combinations(doc)->
-    ["Test schema loaction and extra_db_nodes combinations."];
+    ["Test schema location and extra_db_nodes combinations."];
 schema_location_and_extra_db_nodes_combinations(suite) -> [];
 schema_location_and_extra_db_nodes_combinations(Config) when is_list(Config) ->
     [N1, N2] = Nodes = ?init(2, Config),
diff --git a/lib/mnesia/test/mnesia_consistency_test.erl b/lib/mnesia/test/mnesia_consistency_test.erl
index 46bafaf65c..2a956d6efe 100644
--- a/lib/mnesia/test/mnesia_consistency_test.erl
+++ b/lib/mnesia/test/mnesia_consistency_test.erl
@@ -341,7 +341,7 @@ receive_messages(ListOfMsgs) ->
                     ?verbose("I (~p) got msg ~p from ~p ~n", [self(),Msg, Pid]),
                     [{Pid, Msg} | receive_messages(ListOfMsgs -- [Msg])]
             end;
-        Else -> ?warning("Recevied unexpected Msg~n ~p ~n", [Else])
+        Else -> ?warning("Received unexpected Msg~n ~p ~n", [Else])
     after timer:minutes(3) -> 
             ?error("Timeout in receive msgs while waiting for ~p~n", 
                    [ListOfMsgs])
diff --git a/lib/mnesia/test/mnesia_evil_coverage_test.erl b/lib/mnesia/test/mnesia_evil_coverage_test.erl
index 1c84774e6f..68ab9a53b7 100644
--- a/lib/mnesia/test/mnesia_evil_coverage_test.erl
+++ b/lib/mnesia/test/mnesia_evil_coverage_test.erl
@@ -696,7 +696,7 @@ verify_ll_queue(N) ->
     ?match(granted,mnesia_controller:block_controller()),
     case mnesia_controller:get_info(1000) of
 	{info,{state,_,true,[],_Loader,[],[],[],_,_,_,_,_,_}} ->
-	    %% Very slow SMP machines havn't loaded it yet..
+	    %% Very slow SMP machines haven't loaded it yet..
 	    mnesia_controller:unblock_controller(),
 	    timer:sleep(10),
 	    verify_ll_queue(N-1);
@@ -1295,7 +1295,7 @@ offline_set_master_nodes(Config) when is_list(Config) ->
     ?verify_mnesia(Nodes, []).
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%% Syncronize table with log or disc
+%% Synchronize table with log or disc
 %%
 
 %% Dump ram tables on disc
@@ -2091,7 +2091,7 @@ test_ext_sub(Tab1, Tab2, Tab3) ->
 
 
 subscribe_standard(doc) ->
-    ["Tests system events and the orignal table events"];
+    ["Tests system events and the original table events"];
 subscribe_standard(suite) -> [];
 subscribe_standard(Config) when is_list(Config)-> 
     [N1, N2]=?acquire_nodes(2, Config),
diff --git a/lib/mnesia/test/mnesia_recovery_test.erl b/lib/mnesia/test/mnesia_recovery_test.erl
index b5749408f8..1ef10625b5 100644
--- a/lib/mnesia/test/mnesia_recovery_test.erl
+++ b/lib/mnesia/test/mnesia_recovery_test.erl
@@ -1341,7 +1341,7 @@ garb_of_decisions(Kill, Nodes, Tid_list, Trans_res) ->
 	    case length(Tid_list) of
 		1 -> 
 		    %% If there was only one transaction, it should be logged as
-		    %% comitted on every node!
+		    %% committed on every node!
 		    [Tid1] = Tid_list,
 		    verify_garb_transient_logs(Nodes, [Tid1], committed);
 		2 -> 
@@ -1455,7 +1455,7 @@ receive_messages(ListOfMsgs, File, Line) ->
 		    [{Pid, Msg} | receive_messages(ListOfMsgs -- [Msg], File, Line)]
 	    end;
 	Else -> mnesia_test_lib:log("<>WARNING<>~n"
-				    "Recevied unexpected or bad formatted msg~n ~p ~n"
+				    "Received unexpected or bad formatted msg~n ~p ~n"
 				    "While waiting for ~p~n", 
 	 			    [Else, ListOfMsgs], File, Line),
 		receive_messages(ListOfMsgs, File, Line)
diff --git a/lib/mnesia/test/mnesia_test_lib.erl b/lib/mnesia/test/mnesia_test_lib.erl
index 9794915026..e7fe419dfc 100644
--- a/lib/mnesia/test/mnesia_test_lib.erl
+++ b/lib/mnesia/test/mnesia_test_lib.erl
@@ -62,7 +62,7 @@
 %%% test(TestCases)
 %%%
 %%%    Run parts of the test suite. Uses test/2.
-%%%    Reads Config from mnesia_test.config and starts them if neccessary.
+%%%    Reads Config from mnesia_test.config and starts them if necessary.
 %%%    Kills Mnesia and wipes out the Mnesia directories as a starter.
 %%%
 %%% test(TestCases, Config)
@@ -722,7 +722,7 @@ kill_tc(Pid, Time) ->
 			   "in ~p min~n", [Time div (1000*60)]),
 		    Files = mnesia_lib:dist_coredump(),
 		    ?log("Cores dumped to:~n ~p~n", [Files]),
-		    %% Genarate erlang crashdumps.
+		    %% Generate erlang crashdumps.
 		    %% GenDump = fun(Node) ->
 		    %% 		      File = "CRASH_" ++ atom_to_list(Node) ++ ".dump",
 		    %% 		      rpc:call(Node, os, putenv, ["ERL_CRASH_DUMP", File]),
diff --git a/lib/mnesia/test/mnesia_tpcb.erl b/lib/mnesia/test/mnesia_tpcb.erl
index fb39ee321d..2f2f3a3eb9 100644
--- a/lib/mnesia/test/mnesia_tpcb.erl
+++ b/lib/mnesia/test/mnesia_tpcb.erl
@@ -35,7 +35,7 @@
 %%   a database system.
 %%
 %%   The definition of the TPC-B states lots of detailed rules and
-%%   conditions that must be fullfilled, e.g. how the ACID (atomicity,
+%%   conditions that must be fulfilled, e.g. how the ACID (atomicity,
 %%   consistency, isolation and durability) properties are verified,
 %%   how the random numbers must be distributed, minimum sizes of
 %%   the different types of records, minimum duration of the benchmark,
diff --git a/lib/mnesia/test/mnesia_trans_access_test.erl b/lib/mnesia/test/mnesia_trans_access_test.erl
index 65206a85af..b33b807bfc 100644
--- a/lib/mnesia/test/mnesia_trans_access_test.erl
+++ b/lib/mnesia/test/mnesia_trans_access_test.erl
@@ -722,7 +722,7 @@ nested_transactions(Config, Child, Father) ->
 		     {[{Tab, father, not_updated}], [{Tab, child, not_updated}]}
 	end,
 
-    %% Syncronize things!!
+    %% Synchronize things!!
     ?match({atomic, ok}, mnesia:sync_transaction(fun() -> mnesia:write({Tab, sync, sync}) end)),
 
     ?match(ChildRes, rpc:call(Node1, mnesia, dirty_read, [{Tab, child}])),
@@ -1196,7 +1196,7 @@ index_delete_object(Config) when is_list(Config) ->
     ?verify_mnesia(Nodes, []).
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%% Add and drop indecies
+%% Add and drop indices
 
 
 add_table_index_ram(suite) -> [];
diff --git a/lib/mnesia/test/mnesia_durability_test.erl b/lib/mnesia/test/mnesia_durability_test.erl
index ccbfdc9738..4582543e38 100644
--- a/lib/mnesia/test/mnesia_durability_test.erl
+++ b/lib/mnesia/test/mnesia_durability_test.erl
@@ -503,7 +503,7 @@ load_when_down_from_all_other_replica_nodes(Config) when is_list(Config) ->
     ?match([], mnesia_test_lib:kill_mnesia([N2])),
     ?match({atomic,ok},rpc:call(N3,mnesia,transaction,[Write_one,[33,33]])),
     ?match([], mnesia_test_lib:kill_mnesia([N3])),
-    ?verbose("Mnesia stoped on all three nodes.~n",[]),
+    ?verbose("Mnesia stopped on all three nodes.~n",[]),
 
     %%Start Mnesia on N3; wait for 'test_rec' table to load
     ?match(ok, rpc:call(N3, mnesia, start, [])),
@@ -528,7 +528,7 @@ load_when_down_from_all_other_replica_nodes(Config) when is_list(Config) ->
 late_load_transforms_into_disc_load(doc) ->
     ["Difficult case that needs instrumentation of Mnesia.",
      "A table is force loaded, and Mnesia decides to load it from another ",
-     "Mnesia node because it is avaliable there. The other Mnesia node then ",
+     "Mnesia node because it is available there. The other Mnesia node then ",
      "dies in mid copy which shall make the first Mnesia node to really ",
      "force load from disc.",
      "Check this by starting N1 and N2 and replicating a table between ",
@@ -1028,7 +1028,7 @@ master_nodes(Config) when is_list(Config) ->
     ?match({timeout, [Tab]}, rpc:call(A, mnesia, wait_for_tables, [[Tab], 2000])),
 
     %% Test 6: Force load on table that couldn't be loaded due to master 
-    %%         table setttings, loads other active replicas i.e. from C
+    %%         table settings, loads other active replicas i.e. from C
 
     ?match(yes, rpc:call(A, mnesia, force_load_table, [Tab])),
     ?match(ok, rpc:call(A, mnesia, wait_for_tables, [[Tab], 3000])),
@@ -1041,7 +1041,7 @@ master_nodes(Config) when is_list(Config) ->
     ?match([{Tab, 1, update_2}], rpc:call(C, mnesia, dirty_read, [{Tab, 1}])),
 
     %% Test 7: Master [B] and B is down the table should not be loaded, 
     %%         force_load when there are no active replicas availible 
     %%         should generate a load of a local table
 
     ?match(ok, rpc:call(A, mnesia, set_master_nodes, [Tab, [B]])),
@@ -1138,7 +1138,7 @@ master_on_non_local_tables(Config) when is_list(Config) ->
 remote_force_load_with_local_master_node(doc) ->
     ["Force load a table on a remote node while the ",
      "local node is down. Start the local node and ",
-     "verfify that the tables is loaded from disc locally "
+     "verify that the tables is loaded from disc locally "
      "if the local node has itself as master node and ",
      "the remote node has both the local and remote node ",
      "as master nodes"];
@@ -1345,13 +1345,13 @@ dump_ram_copies(Config) when is_list(Config)  ->
     %% start Mnesia only on node 3
     ?verbose("starting mnesia on Node3~n",[]),
     
-    %% test_lib:mnesia_start doesnt work, because it waits
+    %% test_lib:mnesia_start doesn't work, because it waits
     %% for the schema on all nodes ... ???
     ?match(ok,rpc:call(Node3,mnesia,start,[]) ),
     ?match(ok,rpc:call(Node3,mnesia,wait_for_tables,
 		       [[Tab],timer:seconds(30)]   ) ),
     
-    %% node3  shall have the conents of the dump
+    %% node3  shall have the contents of the dump
     cross_check_tables([C],Tab,{[{Tab,1,4711}],[{Tab,2,42}],[{Tab,3,256}]}),
     
     %% start Mnesia on the other 2 nodes, too
@@ -1569,7 +1569,7 @@ receive_messages(ListOfMsgs) ->
                     [{Pid, Msg} | receive_messages(ListOfMsgs -- [Msg])]
             end;
 
-        Else -> ?warning("Recevied unexpected Msg~n ~p ~n", [Else])
+        Else -> ?warning("Received unexpected Msg~n ~p ~n", [Else])
     after timer:seconds(40) -> 
             ?error("Timeout in receive msgs while waiting for ~p~n", 
                    [ListOfMsgs])
@@ -1041,7 +1041,7 @@ master_nodes(Config) when is_list(Config) ->
 
     %% Test 7: Master [B] and B is down the table should not be loaded, 
-    %%         force_load when there are no active replicas availible 
+    %%         force_load when there are no active replicas available 
     %%         should generate a load of a local table
 
diff --git a/lib/mnesia/test/mnesia_isolation_test.erl b/lib/mnesia/test/mnesia_isolation_test.erl
index a65bfd31e1..5a24e87c62 100644
--- a/lib/mnesia/test/mnesia_isolation_test.erl
+++ b/lib/mnesia/test/mnesia_isolation_test.erl
@@ -902,7 +902,7 @@ snmp_open_table(Config) when is_list(Config) ->
     A ! end_trans,             %% Kill A, locks should be released
     ?match_receive({A,{atomic,end_trans}}),     
     
-    %% Locks released! op should be exec. Can take a while (thats the timeout)
+    %% Locks released! op should be exec. Can take a while (that's the timeout)
     receive 
 	Msg -> ?match({Pid, {atomic, ok}}, Msg)
     after
@@ -934,7 +934,7 @@ snmp_close_table(Config) when is_list(Config) ->
     A ! end_trans,             %% Kill A, locks should be released
     ?match_receive({A,{atomic,end_trans}}),     
     
-    %% Locks released! op should be exec. Can take a while (thats the timeout)
+    %% Locks released! op should be exec. Can take a while (that's the timeout)
     receive 
 	Msg -> ?match({Pid, {atomic, ok}}, Msg)
     after
@@ -1658,7 +1658,7 @@ write_shadows(Config) when is_list(Config) ->
     ?match({atomic, ok}, mnesia:transaction(Fun1)), 
 
     Fun2 = fun() ->
 		  %% write shadow old write - is the confirmed value visable
 		  %%                          in the shadow ?
 		  ?match([RecA1], mnesia:read({Tab, a})), 
 		  ?match([RecA1], mnesia:wread({Tab, a})), 
@@ -1732,14 +1732,14 @@ write_shadows(Config) when is_list(Config) ->
 		  ?match([RecA1], mnesia:index_match_object(PatA1, ValPos)), 
 		  ?match([RecA1], mnesia:index_read(Tab, 1, ValPos)), 
 
 		  %% write shadow new write - is a new value visable instead
 		  %%                          of the old value ?
 		  ?match(ok, mnesia:write(RecA2)), 
 
 		  ?match([RecA2], mnesia:read({Tab, a})), 
 		  ?match([RecA2], mnesia:wread({Tab, a})), 
 		   ?match([],      mnesia:match_object(PatA1)), %% delete shadow old but not new write
-		   ?match([RecA2], mnesia:match_object(PatA2)), %% is the new value visable
+		   ?match([RecA2], mnesia:match_object(PatA2)), %% is the new value visible
 
 		  ?match([a], mnesia:all_keys(Tab)), 
 		  ?match([RecA2], mnesia:index_match_object(PatA2, ValPos)), 
@@ -1792,7 +1792,7 @@ delete_shadows(Config) when is_list(Config) ->
 		  ?match([], mnesia:index_match_object(PatA1, ValPos)), 
 		  ?match([], mnesia:index_read(Tab, 1, ValPos)), 
 
 		  %% delete shadow old but not new write - is the new value visable
 		  %%                           when the old one was deleted ?
 		  ?match(ok, mnesia:write(RecA2)), 
 
@@ -1877,7 +1877,7 @@ write_delete_shadows_bag(Config) when is_list(Config) ->
 		   ?match([], mnesia:index_match_object(PatA1, ValPos)), 
 		   ?match([], mnesia:index_read(Tab, 1, ValPos)), 
 
 		   %% delete shadow old but not new write - are both new value visable
 		   %%                           when the old one was deleted ?
 		   ?match(ok, mnesia:write(RecA2)), 
 		   ?match(ok, mnesia:write(RecA3)), 
@@ -2137,7 +2137,7 @@ removed_resources([_N1,N2,N3], DeleteRes) ->
 nasty(suite) -> [];
 
 nasty(doc) ->
-    ["Tries to fullfill a rather nasty locking scenario, where we have had "
+    ["Tries to fulfill a rather nasty locking scenario, where we have had "
      "bugs, the testcase tries a combination of locks in locker queue"];
 
 %%  This testcase no longer works as it was intended to show errors when 
@@ -1658,7 +1658,7 @@ write_shadows(Config) when is_list(Config) ->
 
     Fun2 = fun() ->
-		  %% write shadow old write - is the confirmed value visable
+		  %% write shadow old write - is the confirmed value visible
 		  %%                          in the shadow ?
 		  ?match([RecA1], mnesia:read({Tab, a})), 
@@ -1732,14 +1732,14 @@ write_shadows(Config) when is_list(Config) ->
 		  ?match([RecA1], mnesia:index_read(Tab, 1, ValPos)), 
 
-		  %% write shadow new write - is a new value visable instead
+		  %% write shadow new write - is a new value visible instead
 		  %%                          of the old value ?
 		  ?match(ok, mnesia:write(RecA2)), 
@@ -1792,7 +1792,7 @@ delete_shadows(Config) when is_list(Config) ->
 		  ?match([], mnesia:index_read(Tab, 1, ValPos)), 
 
-		  %% delete shadow old but not new write - is the new value visable
+		  %% delete shadow old but not new write - is the new value visible
 		  %%                           when the old one was deleted ?
 		  ?match(ok, mnesia:write(RecA2)), 
@@ -1877,7 +1877,7 @@ write_delete_shadows_bag(Config) when is_list(Config) ->
 		   ?match([], mnesia:index_read(Tab, 1, ValPos)), 
 
-		   %% delete shadow old but not new write - are both new value visable
+		   %% delete shadow old but not new write - are both new value visible
 		   %%                           when the old one was deleted ?
 		   ?match(ok, mnesia:write(RecA2)), 
-- 
2.31.1

openSUSE Build Service is sponsored by